@@ -21,13 +21,13 @@ class PonsTranslator(BaseTranslator):
     _languages = PONS_LANGUAGES_TO_CODES
     supported_languages = list(_languages.keys())
 
-    def __init__(self, source, target="english"):
+    def __init__(self, source, target="en", proxies=None):
         """
         @param source: source language to translate from
         @param target: target language to translate to
         """
         self.__base_url = BASE_URLS.get("PONS")
-
+        self.proxies = proxies
         if self.is_language_supported(source, target):
             self._source, self._target = self._map_language_to_code(source, target)
 
@@ -86,7 +86,7 @@ class PonsTranslator(BaseTranslator):
         if self._validate_payload(word, max_chars=50):
             url = "{}{}-{}/{}".format(self.__base_url, self._source, self._target, word)
             url = requote_uri(url)
-            response = requests.get(url)
+            response = requests.get(url, proxies=self.proxies)
 
             if response.status_code == 429:
                 raise TooManyRequests()
@@ -131,6 +131,6 @@ class PonsTranslator(BaseTranslator):
 
         translated_words = []
         for word in words:
-            translated_words.append(self.translate(payload=word))
+            translated_words.append(self.translate(word=word))
         return translated_words
 
